"""
Configuration module for Stockholm

Contains all constants, ticker lists, RSS feeds, and configuration settings.
"""

# Major stock tickers organized by sector
MAJOR_TICKERS = [
    # Tech giants
    "AAPL",
    "MSFT",
    "GOOGL",
    "AMZN",
    "TSLA",
    "META",
    "NVDA",
    "NFLX",
    "ADBE",
    "CRM",
    "ORCL",
    "INTC",
    "AMD",
    # Financial
    "JPM",
    "BAC",
    "WFC",
    "GS",
    "MS",
    "C",
    "BRK-B",
    "V",
    "MA",
    "AXP",
    "COF",
    "USB",
    "PNC",
    "TFC",
    # Healthcare & Pharmaceuticals
    "JNJ",
    "UNH",
    "PFE",
    "ABT",
    "TMO",
    "DHR",
    "BMY",
    "AMGN",
    "GILD",
    "BIIB",
    "REGN",
    "VRTX",
    # Consumer Goods & Retail
    "WMT",
    "HD",
    "PG",
    "KO",
    "PEP",
    "MCD",
    "NKE",
    "SBUX",
    "TGT",
    "COST",
    "LOW",
    "DIS",
    # Industrial & Manufacturing
    "BA",
    "CAT",
    "GE",
    "MMM",
    "HON",
    "UPS",
    "FDX",
    "LMT",
    "RTX",
    "NOC",
    "GD",
    # Energy & Oil
    "XOM",
    "CVX",
    "COP",
    "EOG",
    "SLB",
    "MPC",
    "VLO",
    "PSX",
    "KMI",
    "OKE",
    # Real Estate & REITs
    "AMT",
    "PLD",
    "CCI",
    "EQIX",
    "PSA",
    "EXR",
    "AVB",
    "EQR",
    "SPG",
    "O",
    # Utilities
    "NEE",
    "DUK",
    "SO",
    "D",
    "AEP",
    "EXC",
    "XEL",
    "SRE",
    "PEG",
    "ED",
    # Telecommunications
    "VZ",
    "T",
    "TMUS",
    "CHTR",
    "CMCSA",
    "DISH",
    "LUMN",
    "VG",
    "SIRI",
    "FYBR",
    # Materials & Mining
    "LIN",
    "APD",
    "ECL",
    "SHW",
    "FCX",
    "NEM",
    "GOLD",
    "AA",
    "X",
    "CLF",
    # Aerospace & Defense (Additional)
    "LHX",
    "TDG",
    "LDOS",
    "HII",
    "KTOS",
    "AJRD",
    "TXT",
    "CW",
    "AIR",
    "MRCY",
    # Biotechnology (Specialized)
    "MRNA",
    "BNTX",
    "ILMN",
    "INCY",
    "BMRN",
    "TECH",
    "SGEN",
    "ALNY",
    "RARE",
    "BLUE",
    # ETFs and Indices
    "SPY",
    "QQQ",
    "IWM",
    "DIA",
    "VTI",
    "VOO",
    "VEA",
    "VWO",
    "GLD",
    "SLV",
]

# Market indices for tracking overall market performance
MARKET_INDICES = {
    "SPY": "S&P 500",
    "QQQ": "NASDAQ",
    "DIA": "Dow Jones",
    "IWM": "Russell 2000",
    "VTI": "Total Stock Market",
}

# Government RSS Feeds for Policy News
GOVERNMENT_RSS_FEEDS = {
    "fed_press": {
        "url": "https://www.federalreserve.gov/feeds/press_all.xml",
        "name": "Federal Reserve Press Releases",
        "category": "monetary_policy",
        "impact_weight": 0.9,  # High impact on markets
    },
    "fed_monetary": {
        "url": "https://www.federalreserve.gov/feeds/press_monetary.xml",
        "name": "Fed Monetary Policy",
        "category": "monetary_policy",
        "impact_weight": 1.0,  # Highest impact
    },
    "fed_speeches": {
        "url": "https://www.federalreserve.gov/feeds/speeches.xml",
        "name": "Fed Speeches & Testimony",
        "category": "monetary_policy",
        "impact_weight": 0.7,
    },
    "fed_banking_reg": {
        "url": "https://www.federalreserve.gov/feeds/press_bcreg.xml",
        "name": "Fed Banking Regulation",
        "category": "regulatory",
        "impact_weight": 0.6,
    },
    "fed_enforcement": {
        "url": "https://www.federalreserve.gov/feeds/press_enforcement.xml",
        "name": "Fed Enforcement Actions",
        "category": "regulatory",
        "impact_weight": 0.5,
    },
}

# Policy keywords that indicate market impact
POLICY_KEYWORDS = {
    "high_impact": [
        "interest rate",
        "federal funds rate",
        "monetary policy",
        "quantitative easing",
        "inflation target",
        "recession",
        "economic outlook",
        "gdp growth",
        "unemployment rate",
        "fomc",
        "rate hike",
        "rate cut",
        "dovish",
        "hawkish",
    ],
    "medium_impact": [
        "banking regulation",
        "stress test",
        "capital requirements",
        "liquidity",
        "financial stability",
        "systemic risk",
        "basel",
        "dodd-frank",
        "consumer protection",
        "enforcement action",
    ],
    "sector_specific": [
        "energy policy",
        "healthcare reform",
        "tax policy",
        "trade policy",
        "infrastructure",
        "climate policy",
        "technology regulation",
        "antitrust",
        "merger",
        "acquisition",
    ],
}

# Sector mapping for tickers - Expanded to 12 major sectors
SECTOR_MAPPING = {
    # Technology (Software, Hardware, Internet)
    "AAPL": "Technology",
    "MSFT": "Technology",
    "GOOGL": "Technology",
    "AMZN": "Technology",
    "META": "Technology",
    "NVDA": "Technology",
    "NFLX": "Technology",
    "ADBE": "Technology",
    "CRM": "Technology",
    "ORCL": "Technology",
    "INTC": "Technology",
    "AMD": "Technology",
    "TSLA": "Technology",
    # Financial Services (Banks, Insurance, Payment Processors)
    "JPM": "Financial",
    "BAC": "Financial",
    "WFC": "Financial",
    "GS": "Financial",
    "MS": "Financial",
    "C": "Financial",
    "BRK-B": "Financial",
    "V": "Financial",
    "MA": "Financial",
    "AXP": "Financial",
    "COF": "Financial",
    "USB": "Financial",
    "PNC": "Financial",
    "TFC": "Financial",
    # Healthcare & Pharmaceuticals
    "JNJ": "Healthcare",
    "UNH": "Healthcare",
    "PFE": "Healthcare",
    "ABT": "Healthcare",
    "TMO": "Healthcare",
    "DHR": "Healthcare",
    "BMY": "Healthcare",
    "AMGN": "Healthcare",
    "GILD": "Healthcare",
    "BIIB": "Healthcare",
    "REGN": "Healthcare",
    "VRTX": "Healthcare",
    # Consumer Goods & Retail
    "WMT": "Consumer",
    "HD": "Consumer",
    "PG": "Consumer",
    "KO": "Consumer",
    "PEP": "Consumer",
    "MCD": "Consumer",
    "NKE": "Consumer",
    "SBUX": "Consumer",
    "TGT": "Consumer",
    "COST": "Consumer",
    "LOW": "Consumer",
    "DIS": "Consumer",
    # Industrial & Manufacturing
    "BA": "Industrial",
    "CAT": "Industrial",
    "GE": "Industrial",
    "MMM": "Industrial",
    "HON": "Industrial",
    "UPS": "Industrial",
    "FDX": "Industrial",
    "LMT": "Industrial",
    "RTX": "Industrial",
    "NOC": "Industrial",
    "GD": "Industrial",
    # Energy & Oil
    "XOM": "Energy",
    "CVX": "Energy",
    "COP": "Energy",
    "EOG": "Energy",
    "SLB": "Energy",
    "MPC": "Energy",
    "VLO": "Energy",
    "PSX": "Energy",
    "KMI": "Energy",
    "OKE": "Energy",
    # Real Estate & REITs
    "AMT": "Real Estate",
    "PLD": "Real Estate",
    "CCI": "Real Estate",
    "EQIX": "Real Estate",
    "PSA": "Real Estate",
    "EXR": "Real Estate",
    "AVB": "Real Estate",
    "EQR": "Real Estate",
    "SPG": "Real Estate",
    "O": "Real Estate",
    # Utilities (Electric, Gas, Water)
    "NEE": "Utilities",
    "DUK": "Utilities",
    "SO": "Utilities",
    "D": "Utilities",
    "AEP": "Utilities",
    "EXC": "Utilities",
    "XEL": "Utilities",
    "SRE": "Utilities",
    "PEG": "Utilities",
    "ED": "Utilities",
    # Telecommunications (Wireless, Cable, Internet)
    "VZ": "Telecom",
    "T": "Telecom",
    "TMUS": "Telecom",
    "CHTR": "Telecom",
    "CMCSA": "Telecom",
    "DISH": "Telecom",
    "LUMN": "Telecom",
    "VG": "Telecom",
    "SIRI": "Telecom",
    "FYBR": "Telecom",
    # Materials & Mining (Chemicals, Metals, Mining)
    "LIN": "Materials",
    "APD": "Materials",
    "ECL": "Materials",
    "SHW": "Materials",
    "FCX": "Materials",
    "NEM": "Materials",
    "GOLD": "Materials",
    "AA": "Materials",
    "X": "Materials",
    "CLF": "Materials",
    # Aerospace & Defense (Additional Defense Contractors)
    "LHX": "Aerospace",
    "TDG": "Aerospace",
    "LDOS": "Aerospace",
    "HII": "Aerospace",
    "KTOS": "Aerospace",
    "AJRD": "Aerospace",
    "TXT": "Aerospace",
    "CW": "Aerospace",
    "AIR": "Aerospace",
    "MRCY": "Aerospace",
    # Biotechnology (Specialized Biotech)
    "MRNA": "Biotech",
    "BNTX": "Biotech",
    "ILMN": "Biotech",
    "INCY": "Biotech",
    "BMRN": "Biotech",
    "TECH": "Biotech",
    "SGEN": "Biotech",
    "ALNY": "Biotech",
    "RARE": "Biotech",
    "BLUE": "Biotech",
    # ETFs & Index Funds
    "SPY": "ETF",
    "QQQ": "ETF",
    "IWM": "ETF",
    "DIA": "ETF",
    "VTI": "ETF",
    "VOO": "ETF",
    "VEA": "ETF",
    "VWO": "ETF",
    # Commodities
    "GLD": "Commodities",
    "SLV": "Commodities",
}

# Analysis configuration
ANALYSIS_CONFIG = {
    "max_workers": 10,  # Maximum parallel workers for news fetching
    "articles_per_ticker": 3,  # Number of articles to fetch per ticker
    "articles_per_feed": 5,  # Number of articles to fetch per government feed
    "market_data_days": 30,  # Days of market data to fetch
    "price_change_days": 1,  # Days for price change calculation
    "sentiment_thresholds": {
        "positive": 0.1,
        "negative": -0.1,
        "very_positive": 0.2,
        "very_negative": -0.2,
    },
    "policy_weight": 0.3,  # Weight of policy sentiment in combined analysis
    "market_weight": 0.7,  # Weight of market sentiment in combined analysis
}

# Company name mapping for tickers
COMPANY_NAMES = {
    # Technology
    "AAPL": "Apple Inc.",
    "MSFT": "Microsoft Corporation",
    "GOOGL": "Alphabet Inc.",
    "AMZN": "Amazon.com Inc.",
    "META": "Meta Platforms Inc.",
    "NVDA": "NVIDIA Corporation",
    "NFLX": "Netflix Inc.",
    "ADBE": "Adobe Inc.",
    "CRM": "Salesforce Inc.",
    "ORCL": "Oracle Corporation",
    "INTC": "Intel Corporation",
    "AMD": "Advanced Micro Devices Inc.",
    "TSLA": "Tesla Inc.",
    # Financial Services
    "JPM": "JPMorgan Chase & Co.",
    "BAC": "Bank of America Corp.",
    "WFC": "Wells Fargo & Company",
    "GS": "Goldman Sachs Group Inc.",
    "MS": "Morgan Stanley",
    "C": "Citigroup Inc.",
    "BRK-B": "Berkshire Hathaway Inc.",
    "V": "Visa Inc.",
    "MA": "Mastercard Inc.",
    "AXP": "American Express Company",
    "COF": "Capital One Financial Corp.",
    "USB": "U.S. Bancorp",
    "PNC": "PNC Financial Services Group",
    "TFC": "Truist Financial Corporation",
    # Healthcare & Pharmaceuticals
    "JNJ": "Johnson & Johnson",
    "UNH": "UnitedHealth Group Inc.",
    "PFE": "Pfizer Inc.",
    "ABT": "Abbott Laboratories",
    "TMO": "Thermo Fisher Scientific Inc.",
    "DHR": "Danaher Corporation",
    "BMY": "Bristol Myers Squibb Company",
    "AMGN": "Amgen Inc.",
    "GILD": "Gilead Sciences Inc.",
    "BIIB": "Biogen Inc.",
    "REGN": "Regeneron Pharmaceuticals Inc.",
    "VRTX": "Vertex Pharmaceuticals Inc.",
    # Consumer Goods & Retail
    "WMT": "Walmart Inc.",
    "HD": "Home Depot Inc.",
    "PG": "Procter & Gamble Company",
    "KO": "Coca-Cola Company",
    "PEP": "PepsiCo Inc.",
    "MCD": "McDonald's Corporation",
    "NKE": "Nike Inc.",
    "SBUX": "Starbucks Corporation",
    "TGT": "Target Corporation",
    "COST": "Costco Wholesale Corporation",
    "LOW": "Lowe's Companies Inc.",
    "DIS": "Walt Disney Company",
    # Industrial & Manufacturing
    "BA": "Boeing Company",
    "CAT": "Caterpillar Inc.",
    "GE": "General Electric Company",
    "MMM": "3M Company",
    "HON": "Honeywell International Inc.",
    "UPS": "United Parcel Service Inc.",
    "FDX": "FedEx Corporation",
    "LMT": "Lockheed Martin Corporation",
    "RTX": "Raytheon Technologies Corporation",
    "NOC": "Northrop Grumman Corporation",
    "GD": "General Dynamics Corporation",
    # Energy & Oil
    "XOM": "Exxon Mobil Corporation",
    "CVX": "Chevron Corporation",
    "COP": "ConocoPhillips",
    "EOG": "EOG Resources Inc.",
    "SLB": "Schlumberger Limited",
    "MPC": "Marathon Petroleum Corporation",
    "VLO": "Valero Energy Corporation",
    "PSX": "Phillips 66",
    "KMI": "Kinder Morgan Inc.",
    "OKE": "ONEOK Inc.",
    # Real Estate & REITs
    "AMT": "American Tower Corporation",
    "PLD": "Prologis Inc.",
    "CCI": "Crown Castle Inc.",
    "EQIX": "Equinix Inc.",
    "PSA": "Public Storage",
    "EXR": "Extended Stay America Inc.",
    "AVB": "AvalonBay Communities Inc.",
    "EQR": "Equity Residential",
    "SPG": "Simon Property Group Inc.",
    "O": "Realty Income Corporation",
    # Utilities
    "NEE": "NextEra Energy Inc.",
    "DUK": "Duke Energy Corporation",
    "SO": "Southern Company",
    "D": "Dominion Energy Inc.",
    "AEP": "American Electric Power Company",
    "EXC": "Exelon Corporation",
    "XEL": "Xcel Energy Inc.",
    "SRE": "Sempra Energy",
    "PEG": "Public Service Enterprise Group",
    "ED": "Consolidated Edison Inc.",
    # Telecommunications
    "VZ": "Verizon Communications Inc.",
    "T": "AT&T Inc.",
    "TMUS": "T-Mobile US Inc.",
    "CHTR": "Charter Communications Inc.",
    "CMCSA": "Comcast Corporation",
    "DISH": "DISH Network Corporation",
    "LUMN": "Lumen Technologies Inc.",
    "VG": "Vonage Holdings Corp.",
    "SIRI": "Sirius XM Holdings Inc.",
    "FYBR": "Frontier Communications Parent Inc.",
    # Materials & Mining
    "LIN": "Linde plc",
    "APD": "Air Products and Chemicals Inc.",
    "ECL": "Ecolab Inc.",
    "SHW": "Sherwin-Williams Company",
    "FCX": "Freeport-McMoRan Inc.",
    "NEM": "Newmont Corporation",
    "GOLD": "Barrick Gold Corporation",
    "AA": "Alcoa Corporation",
    "X": "United States Steel Corporation",
    "CLF": "Cleveland-Cliffs Inc.",
    # Aerospace & Defense
    "LHX": "L3Harris Technologies Inc.",
    "TDG": "TransDigm Group Inc.",
    "LDOS": "Leidos Holdings Inc.",
    "HII": "Huntington Ingalls Industries Inc.",
    "KTOS": "Kratos Defense & Security Solutions",
    "AJRD": "Aerojet Rocketdyne Holdings Inc.",
    "TXT": "Textron Inc.",
    "CW": "Curtiss-Wright Corporation",
    "AIR": "AAR Corp.",
    "MRCY": "Mercury Systems Inc.",
    # Biotechnology
    "MRNA": "Moderna Inc.",
    "BNTX": "BioNTech SE",
    "ILMN": "Illumina Inc.",
    "INCY": "Incyte Corporation",
    "BMRN": "BioMarin Pharmaceutical Inc.",
    "TECH": "Bio-Techne Corporation",
    "SGEN": "Seagen Inc.",
    "ALNY": "Alnylam Pharmaceuticals Inc.",
    "RARE": "Ultragenyx Pharmaceutical Inc.",
    "BLUE": "bluebird bio Inc.",
    # ETFs & Index Funds
    "SPY": "SPDR S&P 500 ETF Trust",
    "QQQ": "Invesco QQQ Trust",
    "IWM": "iShares Russell 2000 ETF",
    "DIA": "SPDR Dow Jones Industrial Average ETF",
    "VTI": "Vanguard Total Stock Market ETF",
    "VOO": "Vanguard S&P 500 ETF",
    "VEA": "Vanguard FTSE Developed Markets ETF",
    "VWO": "Vanguard FTSE Emerging Markets ETF",
    # Commodities
    "GLD": "SPDR Gold Shares",
    "SLV": "iShares Silver Trust",
}

# Display configuration
DISPLAY_CONFIG = {
    "top_tickers_count": 25,  # Increased from 5 to show more tickers
    "negative_tickers_count": 5,  # Increased from 3
    "top_sectors_count": 8,  # Increased to show more sectors (was 5)
    "high_impact_articles_count": 3,
    "recent_news_count": 5,
    "separator_length": 70,
}
